@@ -5,8 +5,7 @@ from typing import Tuple
 
 
 def hash_n(text: bytes, numbers: int = 10) -> int:
-    """Hash a string into a number between 0 and `numbers-1`.
-    """
+    """Hash a string into a number between 0 and `numbers-1`."""
     return int(hashlib.md5(text).hexdigest(), 16) % numbers
 
 
@@ -34,8 +33,7 @@ def contrast(
 def random_color(
     text: str, target_contrast: float = 5, rgb: Tuple[float, float, float] = (1, 1, 1),
 ) -> str:
-    """Generate a random color based on the hash of the string.
-    """
+    """Generate a random color based on the hash of the string."""
     hue = int(hashlib.md5(text.encode("utf-8")).hexdigest(), 16) / (2 ** 128)
     saturation = 0.25
     lightness = 1.0
