@@ -82,6 +82,59 @@ def test_process_post(mock_post, fs):
     )
 
 
+def test_process_post_custom_template(mock_post, fs):
+    root = Path("/path/to/blog")
+
+    post_templates = root / "templates/test-theme/posts"
+    fs.create_dir(post_templates)
+    with open(post_templates / "like.html", "w") as fp:
+        fp.write(
+            """
+<p class="p-summary">Liked: <a class="u-like-of" href="{{ post.parsed['like-url'] }}">this link</a></p>
+{{ post.html }}
+""",
+        )
+
+    with freeze_time("2020-01-01T00:00:00Z"):
+        post = mock_post(
+            """
+        subject: I liked this page
+        keywords: blog
+        summary: I really liked this page about dogs
+        type: like
+        like-url: https://dogs.example.com/
+
+        It's cool.
+        """,
+        )
+
+    builder = PostBuilder(root, config)
+    builder.process_post(post)
+
+    with open(post.file_path.with_suffix(".html")) as fp:
+        contents = fp.read()
+    assert (
+        contents
+        == """
+<!DOCTYPE html><html lang="en">
+<head>
+<meta content="article" property="og:type"/>
+<meta content="Post title" property="og:title"/>
+<meta content="This is the post description" property="og:description"/>
+<link href="https://webmention.io/example.com/webmention" rel="webmention" />
+<link href="https://external.example.com/css/basic.css" rel="stylesheet">
+<link href="/css/style.css" rel="stylesheet">
+
+</head>
+<body>
+
+<p class="p-summary">Liked: <a class="u-like-of" href="https://dogs.example.com/">this link</a></p>
+<p>It's cool.</p>
+</body>
+</html>"""
+    )
+
+
 def test_process_post_up_to_date(mock_post, fs):
     root = Path("/path/to/blog")
 
