@@ -25,8 +25,8 @@ def test_run(mocker, fs):
     # create a couple posts
     fs.create_file(root / "posts/one/index.mkd")
     fs.create_file(root / "posts/two/index.mkd")
-    post1 = Post(root / "posts/one/index.mkd")
-    post2 = Post(root / "posts/two/index.mkd")
+    post1 = Post(root, root / "posts/one/index.mkd")
+    post2 = Post(root, root / "posts/two/index.mkd")
     mocker.patch(
         "nefelibata.cli.build.get_posts", return_value=[post1, post2],
     )
@@ -94,8 +94,8 @@ def test_run_build_exists(mocker, fs):
     # create a couple posts
     fs.create_file(root / "posts/one/index.mkd")
     fs.create_file(root / "posts/two/index.mkd")
-    post1 = Post(root / "posts/one/index.mkd")
-    post2 = Post(root / "posts/two/index.mkd")
+    post1 = Post(root, root / "posts/one/index.mkd")
+    post2 = Post(root, root / "posts/two/index.mkd")
     mocker.patch(
         "nefelibata.cli.build.get_posts", return_value=[post1, post2],
     )
@@ -147,8 +147,8 @@ def test_run_no_collect_replies(mocker, fs):
     # create a couple posts
     fs.create_file(root / "posts/one/index.mkd")
     fs.create_file(root / "posts/two/index.mkd")
-    post1 = Post(root / "posts/one/index.mkd")
-    post2 = Post(root / "posts/two/index.mkd")
+    post1 = Post(root, root / "posts/one/index.mkd")
+    post2 = Post(root, root / "posts/two/index.mkd")
     mocker.patch(
         "nefelibata.cli.build.get_posts", return_value=[post1, post2],
     )
@@ -201,8 +201,8 @@ def test_run_post_up_to_date(mocker, fs):
     # create a couple posts
     fs.create_file(root / "posts/one/index.mkd")
     fs.create_file(root / "posts/two/index.mkd")
-    post1 = Post(root / "posts/one/index.mkd")
-    post2 = Post(root / "posts/two/index.mkd")
+    post1 = Post(root, root / "posts/one/index.mkd")
+    post2 = Post(root, root / "posts/two/index.mkd")
     mocker.patch(
         "nefelibata.cli.build.get_posts", return_value=[post1, post2],
     )
@@ -257,7 +257,7 @@ def test_run_skip_symlink(mocker, fs):
 
     # create a first post
     fs.create_file(root / "posts/one/index.mkd")
-    post1 = Post(root / "posts/one/index.mkd")
+    post1 = Post(root, root / "posts/one/index.mkd")
     mocker.patch(
         "nefelibata.cli.build.get_posts", return_value=[post1],
     )
@@ -304,7 +304,7 @@ def test_run_skip_symlink(mocker, fs):
 
     # create a second post
     fs.create_file(root / "posts/two/index.mkd")
-    post2 = Post(root / "posts/two/index.mkd")
+    post2 = Post(root, root / "posts/two/index.mkd")
     mocker.patch(
         "nefelibata.cli.build.get_posts", return_value=[post1, post2],
     )
