@@ -61,6 +61,7 @@ def test_console_new(mocker):
         "publish": False,
         "ROOT_DIR": None,
         "-s": None,
+        "-t": "post",
         "POST": "Hello, world!",
     }
     mocker.patch("nefelibata.console.docopt", return_value=arguments)
@@ -73,7 +74,7 @@ def test_console_new(mocker):
 
     main()
 
-    mock_new.run.assert_called_with(Path("/path/to/blog"), "Hello, world!")
+    mock_new.run.assert_called_with(Path("/path/to/blog"), "Hello, world!", "post")
 
 
 def test_console_build(mocker):
